%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: Generate2DData.m
%
% Description: The script generates periodic signal data by
%              integration of a second order ODE and addition
%              of measurement disturbances.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2003-03-03 - First version ready.
%             2013-09-01 - Restructured, added measurement disturbance
%                          and documentation.
%             2013-09-28 - Minor corrections.
%
% Copyright: Torbjrn Wigren, 2013-09-01.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Definition of simulation time interval
%

Tsampling=0.025; % Sampling period for numerical integration scheme
Tstart=0.0; % Start time of data generation
Tend=50.0; % End time of data generation
%
% Definition of ODE, and sampling instances passed
%

ThisOde='VanDerPol'; % The name of the ODE file used for integration
InitialValue=[-0.5;0.5]; % The intial value of the ODE
SamplingInstances=linspace(Tstart,Tend,round((Tend-Tstart)/Tsampling)); % instances returned by ODE45

%
% Integrate ODE
%

[t,y]=ode45(ThisOde,SamplingInstances,InitialValue); % Matlab built in solver...

%
% Save time for plotting
%

time=t;

%
% Addition of measurement noise, and creation of output(s)
% 

OutputStates=[1]; % States used for output signal generation. Two states are only used by LS2D
sigmaMeasurement=[0.01 0.00]; % Standard deviation of the measurement noise, assumed to be WGN
e=[];
for i=1:size(OutputStates,2) % Output signal generation
    e=[e sigmaMeasurement(1,i)*randn(size(y,1),1)]; % WGN
end
z=[];
for i=1:size(OutputStates,2) % Output signal generation
    z=[z y(:,OutputStates(1,i))+e(:,i)];
end
y_2=y(:,2); % Corrects error

