%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: Generate2DModelData.m
%
% Description: The script simulates the second order ODE obtained by any
%              of the identification methods of the package.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2013-09-29 - First version ready.
%
% Copyright: Torbjrn Wigren, 2013-09-29.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Globals, needed to pass through ode45
%

global thetaG
global ThetaG;
global DimensionF1X1G;
global DimensionF1X2G;
global DimensionF2X1G;
global DimensionF2X2G;

%
% Definition of ODE, and paranmeters that must be passed globally
%

ThisOde='IdentifiedModel'; % The name of the ODE file used for integration

%
% Integrate ODE
%

if (~(exist('theta')))
    theta=[];
end
if (~(exist('DimensionF1X1')))
    DimensionF1X1=0;
    DimensionF1X2=0;
    Theta=theta;
end


thetaG=theta;
ThetaG=Theta;
DimensionF1X1G=DimensionF1X1;
DimensionF1X2G=DimensionF1X2;
DimensionF2X1G=DimensionF2X1;
DimensionF2X2G=DimensionF2X2;

[t,y]=ode45(ThisOde,SamplingInstances,InitialValue); % Matlab built in solver...

%
% Save time for plotting
%

modelTime=t;

