%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: IdentifiedModel.m
%
% Description: This function defines the ode of the identified model.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2013-09-29 - First version ready.
%
% Copyright: Torbjrn Wigren, 2013-09-29.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function ydot=IdentifiedModel(t,y)

%
% Parameters, passed globally
%

global thetaG;
global ThetaG;
global DimensionF1X1G;
global DimensionF1X2G;
global DimensionF2X1G;
global DimensionF2X2G;

%
% initialization
%

ydot=zeros(2,1);

%
% Case with one RHS
%

if ((DimensionF1X1G==0) & (DimensionF1X2G==0))
    Phi2=[]; 
    for i=0:DimensionF2X1G
        for j=0:DimensionF2X2G
            Phi2=[Phi2; y(1)^i*y(2)^j];
        end;
    end;
    RHS = [y(2); thetaG'*Phi2];
end

%
% Case with 2 RHSs
%

if (~((DimensionF1X1G==0) & (DimensionF1X2G==0)))
    Phi1=[]; 
    for i=0:DimensionF1X1G % First RHS
        for j=0:DimensionF1X2G
            Phi1=[Phi1; y(1)^i*y(2)^j];
        end;
    end;
     
    Phi2=[];
    for i=0:DimensionF2X1G % Second RHS
        for j=0:DimensionF2X2G
           Phi2=[Phi2; y(1)^i*y(2)^j];
        end;
    end;
    RHS = [ThetaG(1:(DimensionF1X1G+1)*(DimensionF1X2G+1),1)'*Phi1; ThetaG((DimensionF1X1G+1)*(DimensionF1X2G+1)+1:(DimensionF1X1G+1)*(DimensionF1X2G+1)+(DimensionF2X1G+1)*(DimensionF2X2G+1),1)'*Phi2];
end

%
% Output
%

ydot=RHS;