%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: Plot2DData.m
%
% Description: The script plots the periodic signal data generated by
%              integration of a second order ODE after addition
%              of measurement disturbances.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2002-01-11 - First version ready.
%             2013-09-01 - Restructured, changed to split plotting
%             2013-09-29 - Corrected logical error
%
% Copyright: Torbjrn Wigren, 2013-09-01.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

OutputDimension=size(OutputStates,2); % Determines the number and type of plots

if OutputDimension==1
    figure
    plot(time,z(:,1));
    grid
    xlabel('Time [s]')
    ylabel('Output signal')
    title('Data')
    figure
    plot(z(:,1),y_2)
    grid
    xlabel('z1')
    ylabel('z2')
    title('Phase plane plot of data')
end;
if OutputDimension==2
    figure
    subplot(211)
    plot(time,z(:,1));
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 1')  
    title('Data')
    subplot(212) 
    plot(time,z(:,2));
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 2')
    title('Data')
    figure
    plot(z(:,1),z(:,2))
    grid
    xlabel('z1')
    ylabel('z2')
    title('Phase plane plot of data')
end;
