%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: Plot2DModel.m
%
% Description: The script plots the periodic signal data generated by
%              integration of the second order ODE obtained with
%              identification.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2013-09-29 - First version ready.
%
% Copyright: Torbjrn Wigren, 2013-09-29.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

OutputDimension=size(OutputStates,2); % Determines the number and type of plots

if OutputDimension==1
    figure
    plot(modelTime,y(:,1));
    grid
    xlabel('Time [s]')
    ylabel('Output signal')
    title('Model')
    figure
    plot(y(:,1),y(:,2))
    grid
    xlabel('y1')
    ylabel('y2')
    title('Phase plane plot of model')
    if exist('thetaSave')
        figure
        numberOfThetaSamples=size(thetaSave,2)
        plot(modelTime(1:numberOfThetaSamples,1),thetaSave');
        grid
        xlabel('Time [s]')
        ylabel('Running parameter estimates')
        title('Model')
    end
end;
if OutputDimension==2
    figure
    subplot(211)
    plot(modelTime,y(:,1));
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 1')  
    title('Model')
    subplot(212) 
    plot(modelTime,y(:,2));
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 2')
    title('Model')
    figure
    plot(y(:,1),y(:,2))
    grid
    xlabel('y1')
    ylabel('y2')
    title('Phase plane plot of model')
    if exist('thetaSave')
        figure
        numberOfThetaSamples=size(thetaSave,2)
        plot(modelTime(1:numberOfThetaSamples,1),thetaSave');
        grid
        xlabel('Time [s]')
        ylabel('Running parameter estimates')
        title('Model')
    end;
end;
