%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: Plot2DModelAndData.m
%
% Description: The script plots the periodic signal data generated by
%              integration of the second order ODE obtained with
%              identification, together with the data used for identificaction.
%              Prediction errors are also computed and plotted.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2013-09-29 - First version ready.
%
% Copyright: Torbjrn Wigren, 2013-09-29.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

OutputDimension=size(OutputStates,2); % Determines the number and type of plots

if OutputDimension==1
    
    %
    % Compute prediction errors
    %
    
    predictionError=z(:,1)-y(:,1);
    
    %
    % Plotting...
    %
    
    figure
    plot(modelTime,z(:,1),'g');
    hold on;
    plot(modelTime,y(:,1),'b');
    hold off
    grid
    xlabel('Time [s]')
    ylabel('Output signal')
    title('Model and Data')
    figure
    plot(modelTime,predictionError)
    grid
    xlabel('Time [s]')
    ylabel('Simulated prediction error')
    title('Model and Data')
    if exist('eSave')
        figure
        numberOfErrorSamples=size(eSave,1);
        plot(modelTime(1:numberOfErrorSamples,1),eSave)
        grid
        xlabel('Time [s]')
        ylabel('Running prediction error')
        title('Model and Data')
    end
end;
if OutputDimension==2
    
    %
    % Compute prediction errors
    %
    
    predictionError=z-y;
    
    %
    % Plotting...
    %

    figure
    subplot(211)
    plot(modelTime,z(:,1),'g');
    hold on;
    plot(modelTime,y(:,1),'b');
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 1')  
    title('Model (blue) and data (green)')
    subplot(212) 
    plot(modelTime,z(:,2),'g');
    hold on;
    plot(modelTime,y(:,2),'b');
    hold off;
    grid
    xlabel('Time [s]')
    ylabel('Output signal, state 2')
    title('Model (blue) and data (green)')
    figure
    plot(z(:,1),z(:,2),'g')
    hold on;
    plot(y(:,1),y(:,2),'b')
    hold off;
    grid
    xlabel('y1 and z1')
    ylabel('y2 and z2')
    title('Phase plane plot of model (blue) and data (green)')
    figure
    subplot(211)
    plot(modelTime,predictionError(:,1))
    grid
    xlabel('Time [s]')
    ylabel('Simulated prediction error, first state')
    title('Model and Data')
    subplot(212)
    plot(modelTime,predictionError(:,2))
    grid
    xlabel('Time [s]')
    ylabel('Simulated prediction error, second state')
    title('Model and Data')
end;
