%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% File name: VanDerPol.m
%
% Description: This function defines the Van der Pol equation.
%
% Reference publications: T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Harmonic signal analysis with Kalman filters 
%                         using periodic orbits of nonlinear ODEs", 
%                         Proc. ICASSP 2003, Hong Kong, China, vol. VI, pp. 669-672, 2003.
%
%                         T. Wigren, E. Abd-Elrady and T. Sderstrm, 
%                         "Least squares harmonic signal analysis using 
%                         periodic orbits of ODEs", Prep. 13:th IFAC Symposium 
%                         on System Identification , Rotterdam, The Netherlands, 
%                         pp.1584-1589, August 27-29, 2003.
%
%                         http://www.it.uu.se/katalog/tw/research/periodicSignalEstimation
%
% Change log: 2002-01-18 - First version ready.
%             2013-09-01 - Documentation added.
%
% Copyright: Torbjrn Wigren, 2013-09-01.
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


function ydot=VanDerPol(t,y)

%
% Parameters
%

eps=2;

%
% Output
%

ydot=[y(2); eps*(1-y(1)^2)*y(2)-y(1)];